- Analyze markup of a page first before implementing a feature
- Use `uv` instead of `pip`
- When writing a scraper, examine the html first and use an explicit element. Do not find by some random keywords.
- Inspect the HTML. Do not take screenshots for debugging purposes.
- Inspect the HTML. Do not wait for an element with a timeout.
- Inspect the HTML. Do not guess the element.
- There's no need to wait for the page to click anything.
- Do not create a README
- When implementing a scraper, do not add screenshot methods for debugging. Inspect HTML instead.
- Scraper tests should use mocked HTMLs as fixtures
- Tests should verify that all functionality works correctly with the fixture HTMLs
- Do not use special mocking beyond the fixture HTMLs
- All tests must pass; tests marked as 'expected to fail' are not allowed